@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright 2013 Red Hat, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,6 +13,7 @@
 #    under the License.
 
 import datetime
+import warnings
 
 import iso8601
 import mock
@@ -285,9 +285,6 @@ class TestUUID(TestField):
             ('da66a411-af0e-4829-9b67-475017ddz152',
                 'da66a411-af0e-4829-9b67-475017ddz152'),
             ('fake_uuid', 'fake_uuid'),
-            (u'fake_uāid', u'fake_uāid'),
-            (b'fake_u\xe1id'.decode('latin_1'),
-                b'fake_u\xe1id'.decode('latin_1')),
             ('1', '1'),
             (1, '1')
         ]
@@ -300,6 +297,11 @@ class TestUUID(TestField):
         self.test_from_primitive()
         self.test_to_primitive()
 
+    def test_validation_warning_can_be_escalated_to_exception(self):
+        warnings.filterwarnings(action='error')
+        self.assertRaises(FutureWarning, self.field.coerce, 'obj', 'attr',
+                          'not a uuid')
+
     def test_get_schema(self):
         field = fields.UUIDField()
         schema = field.get_schema()
